process_input

Function process_input 

pub fn process_input(
    input: Box<dyn Read + 'static>,
    writer: &mut impl Write,
) -> Result<()>
Take a Medusa trace as input, parse it and create Foundry reproducer function for every failing properties

use either by piping the medusa process, medusa fuzz | youdusa either from a txt file, youdusa --file log.txt